-- Credits: phyber
if Fence:HasModule('Wipe') then return end

local mod = Fence:NewModule("Wipe")

local _G = getfenv(0)
local L = AceLibrary("AceLocale-2.2"):new("Fence_Wipe")
local l = AceLibrary("AceLocale-2.2"):new("Fence")

L:RegisterTranslations("enUS", function() return {
	["Wipe"] = true,
	["Wipe options"] = true,
	["Restore"] = true,
	["Restores the button to its default position"] = true,
	["Clear"] = true,
	["Resets the AH-Browse view to its defaults"] = true,
	["Hide Dressing-Room"] = true,
	["Hides the Dressing-Room on reset."] = true,
	["Show"] = true,
	["Shows or hides the button."] = true,
	["Auto"] = true,
	["Resets automatically on opening the auction frame."] = true,
	["Toggles the tooltip display."] = true,
	["Usable"] = true,
	["Disable usable items on reset."] = true,
	["Reset"] = true,
	["Tooltip"] = true,
	["Resets the browser view to its defaults."] = true
} end)

L:RegisterTranslations("deDE", function() return {
	["Wipe"] = "Wipe",
	["Wipe options"] = "Wipe Optionen",
	["Restore"] = "Button zur\195\188cksetzen",
	["Restores the button to its default position"] = "Stellt die Originalposition des Buttons wieder her.",
	["Clear"] = "Reset",
	["Resets the AH-Browse view to its defaults"] = "Setzt die AH Suchanzeige auf die Standardwerte zur\195\188ck.",
	["Hide Dressing-Room"] = "Charaktervorschau",
	["Hides the Dressing-Room on reset."] = "Versteckt das Vorschau-Fenster, sobald der Reset-Button gedr\195\188ckt wird.",
	["Show"] = "Zeige Button",
	["Shows or hides the button."] = "Schaltet die Anzeige des Buttons ein/aus.",
	["Auto"] = "Auto",
	["Resets automatically on opening the auction frame."] = "Setzt Suchanzeige beim \195\150ffnen automatisch zur\195\188ck.",
	["Toggles the tooltip display."] = "Schaltet die Tooltip-Anzeige ein/aus.",
	["Usable"] = "Benutzbare Gegenst\195\164nde",
	["Disable usable items on reset."] = "Benutzbare Gegenst\195\164\nde bei Reset ausschalten.",
	["Reset"] = "Reset",
	["Tooltip"] = "Tooltip",
	["Resets the browser view to its defaults."] = "Setzt die Suchanzeige auf die Standardwerte zur\195\188ck."
} end)

function mod:OnInitialize()
	self.db = Fence:AcquireDBNamespace("Wipe")
	-- Register some defaults.
	if self.db.profile.Show == nil then self.db.profile.Show = true end
	if self.db.profile.Tooltip == nil then self.db.profile.Tooltip = true end
	if self.db.profile.Usable == nil then self.db.profile.Usable = false end
	if self.db.profile.HideDR == nil then self.db.profile.HideDR = true end
	if not self.db.profile.PosX then self.db.profile.PosX = 746 end
	if not self.db.profile.PosY then self.db.profile.PosY = -14 end

	Fence.options.args.wipe = {
		desc = L["Wipe options"],
		type = "group",
		name = L["Wipe"], aliases = 'w',
		args = {
			toggle = {
				type = 'toggle',
				name = L["Wipe"],
				desc = string.format(l["Toggles %s function."], L["Wipe"]),
				get = function() return Fence:IsModuleActive("Wipe") end,
				set = function(v) Fence:ToggleModuleActive("Wipe", v) end,
			},
			restore = {
				name = L["Restore"],
				desc = L["Restores the button to its default position"],
				type = "execute",
				func = function()
					self.db.profile.PosX = 746
					self.db.profile.PosY = -14
					FWButton:ClearAllPoints()
					FWButton:SetPoint("TOPLEFT", "AuctionFrameBrowse", "TOPLEFT", 746, -14)
				end,
			},
			clear = {
				name = L["Clear"],
				desc = L["Resets the AH-Browse view to its defaults"],
				type = "execute",
				func = function() self:Wipe() end,
			},
			hidedr = {
				name = L["Hide Dressing-Room"],
				desc = L["Hides the Dressing-Room on reset."],
				type = "toggle",
				get = function() return self.db.profile.HideDR end,
				set = function(val) self.db.profile.HideDR = val end,
			},
			show = {
				name = L["Show"],
				desc = L["Shows or hides the button."],
				type = "toggle",
				get = function() return self.db.profile.Show end,
				set = function(val)
					self.db.profile.Show = val
					if self.db.profile.Show then
						FWButton:Show()
					else
						FWButton:Hide()
					end
				end,
			},
			auto = {
				name = L["Auto"],
				desc = L["Resets automatically on opening the auction frame."],
				type = "toggle",
				get = function() return self.db.profile.Auto end,
				set = function(val) self.db.profile.Auto = val end,
			},
			tooltip = {
				name = L["Tooltip"],
				desc = L["Toggles the tooltip display."],
				type = "toggle",
				get = function() return self.db.profile.Tooltip end,
				set = function(val) self.db.profile.Tooltip = val end,
			},
			usable = {
				name = L["Usable"],
				desc = L["Disable usable items on reset."],
				type = "toggle",
				get = function() return self.db.profile.Usable end,
				set = function(val) self.db.profile.Usable = val end,
			},

		},
	}
end

function mod:OnEnable()
	if not self.booted then
		self:RegisterEvent("AH_LOADED")
	end
	-- if we're enabled while the AH frame is open
	if AuctionFrameBrowse and AuctionFrameBrowse:IsVisible() then
		if self.booted then
			self:Start()
		else
			-- we're not booted yet, create the button, etc.
			self:AH_LOADED()
		end
	end
end

function mod:OnDisable()
	FWButton:Hide()
end

function mod:MakeButton()
	local FWButton = CreateFrame("Button", "FWButton", AuctionFrameBrowse, "UIPanelButtonTemplate")
	FWButton:SetWidth(60)
	FWButton:SetHeight(19)
	FWButton:SetMovable(true)
	FWButton:RegisterForDrag("RightButton")
	FWButton:RegisterForClicks("LeftButtonDown")
	FWButton:SetScript("OnClick", function() self:Wipe() end)
	FWButton:SetScript("OnDragStart", function()
		if IsShiftKeyDown() then
			FWButton:StartMoving()
		end
	end)
	FWButton:SetScript("OnDragStop", function()
		FWButton:StopMovingOrSizing()
		self:SavePosition()
	end)
	FWButton:SetScript("OnEnter", function() self:Tooltip() end)
	FWButton:SetScript("OnLeave", function() GameTooltip:Hide() end)
	FWButton:SetFrameStrata("HIGH")
	FWButton:SetPoint("TOPLEFT", "AuctionFrameBrowse", "TOPLEFT", self.db.profile.PosX, self.db.profile.PosY)
	FWButton:SetText(L["Reset"])
	FWButton:Hide()
end

function mod:AH_LOADED()
	self.booted = true
	self:MakeButton()
	self:UnregisterEvent("AH_LOADED")
	self:RegisterEvent("AUCTION_HOUSE_SHOW", "Start")
	self:Start()
end

function mod:Start()
	if self.db.profile.Show then 
		FWButton:Show()
	end
	if self.db.profile.Auto then
		self:Wipe()
	end
end

function mod:Tooltip()
	if self.db.profile.Tooltip then
		GameTooltip_SetDefaultAnchor(GameTooltip, this)
		GameTooltip:AddLine(string.format("%s %s", Fence.name, L["Wipe"]))
		GameTooltip:AddLine(L["Resets the browser view to its defaults."], 1, 1, 1)
		GameTooltip:Show()
	end
end

function mod:SavePosition()
	local cx, cy = AuctionFrameBrowse:GetLeft(), AuctionFrameBrowse:GetTop() 
	local ax, ay = FWButton:GetLeft(), FWButton:GetTop() 
	self.db.profile.PosX = ax - cx
	self.db.profile.PosY = ay - cy
	FWButton:ClearAllPoints()
	FWButton:SetPoint("TOPLEFT", "AuctionFrameBrowse", "TOPLEFT", self.db.profile.PosX, self.db.profile.PosY)
end

function mod:Wipe()
	PlaySound("igMainMenuOptionCheckBoxOn")
	if self.db.profile.Usable then
		IsUsableCheckButton:SetChecked(false)
	end
	UIDropDownMenu_SetSelectedValue(BrowseDropDown, -1)
	AuctionFrameBrowse.selectedClass = nil
	AuctionFrameBrowse.selectedClassIndex = nil
	AuctionFrameFilters_Update()
	BrowseName:SetText("")
	BrowseName:SetFocus()
	BrowseMinLevel:SetText("")
	BrowseMaxLevel:SetText("")
	AuctionDressUpModel:Dress()
	if self.db.profile.HideDR then
		ShowOnPlayerCheckButton:SetChecked(false)
		SHOW_ON_CHAR = "0"
		HideUIPanel(AuctionDressUpFrame)
	end
end
